# Generated by Django 5.2.4 on 2025-07-31 07:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("aldryn_forms", "0022_urlfieldplugin"),
    ]

    operations = [
        migrations.AlterField(
            model_name="formplugin",
            name="action_backend",
            field=models.CharField(
                choices=[
                    ("none", "No action"),
                    ("email_only", "Only send email"),
                    ("default", "Save to site administration and send email"),
                ],
                default="default",
                max_length=15,
                verbose_name="Action backend",
            ),
        ),
        migrations.AlterField(
            model_name="submittedtobesent",
            name="language",
            field=models.CharField(
                choices=[("en", "English")],
                default="en",
                max_length=10,
                verbose_name="form language",
            ),
        ),
    ]
