# Generated by Django 4.2.20 on 2025-04-29 13:38

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('aldryn_forms', '0022_formplugin_redirect_to'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='formplugin',
            name='redirect_page',
        ),
        migrations.RemoveField(
            model_name='formplugin',
            name='redirect_type',
        ),
        migrations.RemoveField(
            model_name='formplugin',
            name='url',
        ),
    ]
