# Generated by Django 4.2.20 on 2025-03-21 08:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aldryn_forms', '0020_webhook'),
    ]

    operations = [
        migrations.AddField(
            model_name='formsubmission',
            name='honeypot_filled',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='submittedtobesent',
            name='honeypot_filled',
            field=models.BooleanField(default=False),
        ),
    ]
