{% load aldryn_forms_admin_tags %}
{# settings: ALDRYN_FORMS_SUBMISSION_LIST_DISPLAY_FIELD = "aldryn_forms.admin.display_form_submission_data" #}
{% spaceless %}<span class="aldryn-forms-data">{% for field in data %}
{% if field.value %}
    <span class="item{% if not forloop.first %} more{% endif %}">
        <span class="label">{{ field.label }}</span>
        <span class="value">{{ field.value|media_filer_public_link }}</span>
    </span>
{% endif %}
{% endfor %}</span>{% endspaceless %}
