# Generated by Django 5.2.5 on 2025-09-02 09:08

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("aldryn_forms", "0023_alter_formplugin_action_backend_and_more"),
        ("aldryn_forms", "0023_remove_formplugin_redirect_page_and_more"),
    ]

    operations = []
