# Generated by Django 5.2.6 on 2025-10-21 06:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("aldryn_forms", "0024_merge_20250902_1108"),
    ]

    operations = [
        migrations.AlterField(
            model_name="formplugin",
            name="action_backend",
            field=models.CharField(
                default="default", max_length=15, verbose_name="Action backend"
            ),
        ),
        migrations.AlterField(
            model_name="formsubmission",
            name="language",
            field=models.CharField(max_length=10, verbose_name="form language"),
        ),
        migrations.AlterField(
            model_name="submittedtobesent",
            name="language",
            field=models.CharField(max_length=10, verbose_name="form language"),
        ),
    ]
