from django.apps import AppConfig


class EmailNotifications(AppConfig):
    name = 'aldryn_forms.contrib.email_notifications'
    verbose_name = 'Email notifications'
    default_auto_field = "django.db.models.BigAutoField"
