.readonly {
    max-width: max-content;
    width: auto;
}

.readonly .submitted-data th {
    color: #fff;
    background-color: #00bbff;
}

.readonly .submitted-data td {
    line-height: normal;
    padding: 1em;
}

.readonly .submitted-data td:first-child {
    color: #00bbff;
}

.readonly .submitted-data tr:hover td {
    background-color: #e8f8ff;
}

.readonly .submitted-data td a {
    display: block;
}

.readonly .submitted-data td a:hover {
    text-decoration: underline;
}
