table thead th .text span:has(+ .item-after),
table thead th .text span.item-after
{
    display: inline;
}

table thead th .text span.item-after {
    margin-left: 1em;
}

.aldryn-forms-data .item {
    display: flex;
}

.aldryn-forms-data .item:hover {
    background-color: #e8f8ff;
}

.aldryn-forms-data .item.d-none {
    display: none;
}

.aldryn-forms-data .label {
    color: #00bbff;
}

.aldryn-forms-data .label {
    margin-right: 0.2em;
}

.aldryn-forms-data .label::after {
    content: ":";
}

.aldryn-forms-data .item .value {
    white-space: normal;
}

.aldryn-forms-data .item .value a {
    display: block;
    margin-top: 0.2em;
}

.aldryn-forms-data .item .value a:hover {
    text-decoration: underline;
}

table td .aldryn-forms-data .item-after {
    position: relative;
}

table td .aldryn-forms-data .item-after img {
    position: absolute;
    left: -24px;
    top: 4px;
    visibility: hidden;
}

table tr:hover td .aldryn-forms-data .item-after img {
    visibility: visible;
}

.change-list #changelist .aldryn-forms-formsubmission table tbody td:nth-child(7),
.change-list #changelist .aldryn-forms-formsubmission table tbody th
{
  white-space: normal;
}
